excerpts.Excerpt (Excerpt) — amici1

# `excerpts.Excerpt` (Excerpt)

Excerpt(id, build_time, build_method, user, owner_type, owner_id, company, contact_person, contact_role, excerpt_type, language)

Master tables : excerpts.AllExcerpts (Excerpts), excerpts.Excerpts (Excerpts), excerpts.MyExcerpts (My Excerpts)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- build time (build_time) : Timestamp of the built target file. Contains None if no build hasn’t been called yet.

- Print method (build_method) : See `<lino.core.choicelists.ChoiceListField: build_method>`.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- Controlled by (type) (owner_type) : See `<django.db.models.fields.related.ForeignKey: owner_type>`.

- Controlled by (object) (owner_id) : See `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`.

- Recipient (Organization) (company) : The optional company of the recipient of this excerpt. See ContactRelated.company.

- Recipient (Person) (contact_person) : The optional contact person of the recipient of this excerpt. See ContactRelated.contact_person.

- represented as (contact_role) : The optional Role of the contact_person within company.

- Excerpt Type (excerpt_type) : The type of this excerpt (ForeignKey to ExcerptType).

- Language (language) : The language used for printing this excerpt.

- Body template (body_template_content) : See `lino_xl.lib.excerpts.models.Excerpt.body_template_content`.

- Preview (preview) : See `lino_xl.lib.excerpts.models.Excerpt.preview`.

- Name (name_column) : See `lino_xl.lib.excerpts.models.Excerpt.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.excerpts.models.Excerpt.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.excerpts.models.Excerpt.overview`.

Referenced from courses.Enrolment.printed_by

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
build_time | build time | Timestamp of the built target file. Contains None if no build hasn’t been called yet.
build_method | Print method |
user | Author | The author of this object. A pointer to lino.modlib.users.models.User.
owner_type | Controlled by (type) |
owner_id | Controlled by (object) |
company | Recipient (Organization) | The optional company of the recipient of this excerpt. See ContactRelated.company.
contact_person | Recipient (Person) | The optional contact person of the recipient of this excerpt. See ContactRelated.contact_person.
contact_role | represented as | The optional Role of the contact_person within company.
excerpt_type | Excerpt Type | The type of this excerpt (ForeignKey to ExcerptType).
language | Language | The language used for printing this excerpt.
owner | Controlled by | The object being printed by this excerpt. See Controllable.owner.
body_template_content | Body template |
preview | Preview |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |